# Installation

## Install via conda

You can [install Anaconda or Miniconda](https://conda.io/projects/continuumio-conda/en/latest/user-guide/install/index.html) to obtain conda, and install ReacNetGenerator easily with conda:

```bash
conda install reacnetgenerator -c conda-forge
```

## Install via pip

[![Nbviewer](https://img.shields.io/badge/render-nbviewer-orange)](https://nbviewer.jupyter.org/github/tongzhugroup/reacnetgenerator/blob/master/tutorial/install.ipynb?flush_cache=false)
[![Colab](https://images.weserv.nl/?url=colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/tongzhugroup/reacnetgenerator/blob/master/tutorial/install.ipynb)

```bash
pip install reacnetgenerator
```

See [the build guide](build.md) if you want to build ReacNetGenerator from source. 